from django.apps import AppConfig


class APPNAMEConfig(AppConfig):
    name = "APPNAME"
